@@ -14,7 +14,7 @@ class HltMkbTap(BaseModel):
     is_main = models.BooleanField(db_column="isMain", default=False)
     comments = models.CharField(db_column="Comments", max_length=4096, default="")
     flags = models.IntegerField(db_column="FLAGS", default=0)
-    registration_end_reason_id = models.IntegerField(db_column="rf_kl_RegistrationEndReasonID")
+    registration_end_reason_id = models.IntegerField(db_column="rf_kl_RegistrationEndReasonID", default=0)
     disease_type = models.ForeignKey("OmsKlDiseaseType", db_column="rf_kl_DiseaseTypeID", **FK_DEFAULT)
     trauma_type_id = models.IntegerField(db_column="rf_kl_TraumaTypeID", default=0)
     disp_reg_state_id = models.IntegerField(db_column="rf_kl_DispRegStateID", default=0)
