@@ -57,7 +57,7 @@ class HltTap(BaseModel):
     create_user = models.ForeignKey("XUser", db_column="rf_CreateUserID", **FK_DEFAULT)
     edit_user = models.ForeignKey("XUser", db_column="rf_EditUserID", **FK_DEFAULT)
     stat_cure_result = models.ForeignKey("OmsKlStatCureResult", db_column="rf_kl_StatCureResultID", **FK_DEFAULT)
-    polis_mkab_id = models.IntegerField(db_column="rf_PolisMKABID", default=0)
+    polis_mkab = models.ForeignKey("HltPolisMkab", db_column="rf_PolisMKABID", **FK_DEFAULT)
     type_tap_id = models.IntegerField(db_column="rf_TypeTAPID", default=0)
     registr_patient_id = models.IntegerField(db_column="rf_RegistrPatientID", default=0)
     doc_prvd = models.ForeignKey("HltDocPrvd", db_column="rf_DocPRVDID", **FK_DEFAULT)
